Class: ShellSmartPayApi::AccessTokenErrorException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- ShellSmartPayApi::AccessTokenErrorException
- Defined in:
- lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb
Overview
AccessTokenError class.
Instance Attribute Summary collapse
-
#error ⇒ String
TODO: Write general description for this method.
-
#error_code ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ AccessTokenErrorException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ AccessTokenErrorException
The constructor.
23 24 25 26 27 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 18 def error @error end |
#error_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 14 def error_code @error_code end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
44 45 46 47 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 44 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, error: #{@error.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
38 39 40 41 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 38 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, error: #{@error}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 |
# File 'lib/shell_smart_pay_api/exceptions/access_token_error_exception.rb', line 32 def unbox(hash) @error_code = hash.key?('errorCode') ? hash['errorCode'] : SKIP @error = hash.key?('error') ? hash['error'] : SKIP end |