Class: ShellSmartPayApi::CancelFuelingRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellSmartPayApi::CancelFuelingRequest
- Defined in:
- lib/shell_smart_pay_api/models/cancel_fueling_request.rb
Overview
CancelFuelingRequest Model.
Instance Attribute Summary collapse
-
#mpp_transaction_id ⇒ String
TODO: Write general description for this method.
-
#reason_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mpp_transaction_id = SKIP, reason_code = SKIP) ⇒ CancelFuelingRequest
constructor
A new instance of CancelFuelingRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mpp_transaction_id = SKIP, reason_code = SKIP) ⇒ CancelFuelingRequest
Returns a new instance of CancelFuelingRequest.
41 42 43 44 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 41 def initialize(mpp_transaction_id = SKIP, reason_code = SKIP) @mpp_transaction_id = mpp_transaction_id unless mpp_transaction_id == SKIP @reason_code = reason_code unless reason_code == SKIP end |
Instance Attribute Details
#mpp_transaction_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 14 def mpp_transaction_id @mpp_transaction_id end |
#reason_code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 18 def reason_code @reason_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mpp_transaction_id = hash.key?('mppTransactionId') ? hash['mppTransactionId'] : SKIP reason_code = hash.key?('reasonCode') ? hash['reasonCode'] : SKIP # Create object from extracted values. CancelFuelingRequest.new(mpp_transaction_id, reason_code) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mpp_transaction_id'] = 'mppTransactionId' @_hash['reason_code'] = 'reasonCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 29 def self.optionals %w[ mpp_transaction_id reason_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 71 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} mpp_transaction_id: #{@mpp_transaction_id.inspect}, reason_code:"\ " #{@reason_code.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/shell_smart_pay_api/models/cancel_fueling_request.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} mpp_transaction_id: #{@mpp_transaction_id}, reason_code: #{@reason_code}>" end |