Class: ShellSmartPayApi::CollectingCompany
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellSmartPayApi::CollectingCompany
- Defined in:
- lib/shell_smart_pay_api/models/collecting_company.rb
Overview
CollectingCompany Model.
Instance Attribute Summary collapse
-
#col_co_id ⇒ String
The ID of the Collecting Company (in GFN), also known as Shell Code of the selected payer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(col_co_id = nil) ⇒ CollectingCompany
constructor
A new instance of CollectingCompany.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(col_co_id = nil) ⇒ CollectingCompany
Returns a new instance of CollectingCompany.
35 36 37 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 35 def initialize(col_co_id = nil) @col_co_id = col_co_id end |
Instance Attribute Details
#col_co_id ⇒ String
The ID of the Collecting Company (in GFN), also known as Shell Code of the selected payer. This property is mandatory if the ColCoCode code is not passed
16 17 18 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 16 def col_co_id @col_co_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. col_co_id = hash.key?('ColCoId') ? hash['ColCoId'] : nil # Create object from extracted values. CollectingCompany.new(col_co_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['col_co_id'] = 'ColCoId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} col_co_id: #{@col_co_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/shell_smart_pay_api/models/collecting_company.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} col_co_id: #{@col_co_id}>" end |