Class: ShellSmartPayApi::FaultResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellSmartPayApi::FaultResponse
- Defined in:
- lib/shell_smart_pay_api/models/fault_response.rb
Overview
An error response.
Instance Attribute Summary collapse
-
#fault ⇒ Fault
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fault = SKIP) ⇒ FaultResponse
constructor
A new instance of FaultResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fault = SKIP) ⇒ FaultResponse
Returns a new instance of FaultResponse.
35 36 37 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 35 def initialize(fault = SKIP) @fault = fault unless fault == SKIP end |
Instance Attribute Details
#fault ⇒ Fault
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 14 def fault @fault end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fault = Fault.from_hash(hash['fault']) if hash['fault'] # Create object from extracted values. FaultResponse.new(fault) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['fault'] = 'fault' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 24 def self.optionals %w[ fault ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} fault: #{@fault.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/shell_smart_pay_api/models/fault_response.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} fault: #{@fault}>" end |