Class: ShellSmartPayApi::Payment
- Defined in:
- lib/shell_smart_pay_api/models/payment.rb
Overview
Payment Model.
Instance Attribute Summary collapse
-
#card_id ⇒ String
TODO: Write general description for this method.
-
#card_last_digits ⇒ String
TODO: Write general description for this method.
-
#method ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(method = SKIP, card_id = SKIP, card_last_digits = SKIP) ⇒ Payment
constructor
A new instance of Payment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(method = SKIP, card_id = SKIP, card_last_digits = SKIP) ⇒ Payment
Returns a new instance of Payment.
47 48 49 50 51 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 47 def initialize(method = SKIP, card_id = SKIP, card_last_digits = SKIP) @method = method unless method == SKIP @card_id = card_id unless card_id == SKIP @card_last_digits = card_last_digits unless card_last_digits == SKIP end |
Instance Attribute Details
#card_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 18 def card_id @card_id end |
#card_last_digits ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 22 def card_last_digits @card_last_digits end |
#method ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 14 def method @method end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. method = hash.key?('method') ? hash['method'] : SKIP card_id = hash.key?('cardId') ? hash['cardId'] : SKIP card_last_digits = hash.key?('cardLastDigits') ? hash['cardLastDigits'] : SKIP # Create object from extracted values. Payment.new(method, card_id, card_last_digits) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['method'] = 'method' @_hash['card_id'] = 'cardId' @_hash['card_last_digits'] = 'cardLastDigits' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 34 def self.optionals %w[ method card_id card_last_digits ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} method: #{@method.inspect}, card_id: #{@card_id.inspect}, card_last_digits:"\ " #{@card_last_digits.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/shell_smart_pay_api/models/payment.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} method: #{@method}, card_id: #{@card_id}, card_last_digits:"\ " #{@card_last_digits}>" end |