Class: ShellSmartPayApi::PaymentEnablementErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- ShellSmartPayApi::PaymentEnablementErrorResponseException
- Defined in:
- lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb
Overview
PaymentEnablementErrorResponse class.
Instance Attribute Summary collapse
-
#code ⇒ Integer
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ PaymentEnablementErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ PaymentEnablementErrorResponseException
The constructor.
23 24 25 26 27 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#code ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 14 def code @code end |
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 18 def end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
44 45 46 47 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 44 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, message: #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
38 39 40 41 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 38 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, message: #{@message}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 |
# File 'lib/shell_smart_pay_api/exceptions/payment_enablement_error_response_exception.rb', line 32 def unbox(hash) @code = hash.key?('code') ? hash['code'] : SKIP = hash.key?('message') ? hash['message'] : SKIP end |