Class: ShellSmartPayApi::PaymentEnablementResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellSmartPayApi::PaymentEnablementResponse
- Defined in:
- lib/shell_smart_pay_api/models/payment_enablement_response.rb
Overview
PaymentEnablementResponse Model.
Instance Attribute Summary collapse
-
#dpan_last4 ⇒ String
DPan Last number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dpan_last4 = nil) ⇒ PaymentEnablementResponse
constructor
A new instance of PaymentEnablementResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dpan_last4 = nil) ⇒ PaymentEnablementResponse
Returns a new instance of PaymentEnablementResponse.
33 34 35 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 33 def initialize(dpan_last4 = nil) @dpan_last4 = dpan_last4 end |
Instance Attribute Details
#dpan_last4 ⇒ String
DPan Last number
14 15 16 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 14 def dpan_last4 @dpan_last4 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dpan_last4 = hash.key?('dpanLast4') ? hash['dpanLast4'] : nil # Create object from extracted values. PaymentEnablementResponse.new(dpan_last4) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['dpan_last4'] = 'dpanLast4' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} dpan_last4: #{@dpan_last4.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/shell_smart_pay_api/models/payment_enablement_response.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} dpan_last4: #{@dpan_last4}>" end |