Class: ShellSmartPayApi::StationLocatorUnauthorizedException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- ShellSmartPayApi::StationLocatorUnauthorizedException
- Defined in:
- lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb
Overview
StationLocatorUnauthorized class.
Instance Attribute Summary collapse
-
#error_code ⇒ String
TODO: Write general description for this method.
-
#error_description ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ StationLocatorUnauthorizedException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ StationLocatorUnauthorizedException
The constructor.
23 24 25 26 27 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 14 def error_code @error_code end |
#error_description ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 18 def error_description @error_description end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
45 46 47 48 49 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 45 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, error_description:"\ " #{@error_description.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
39 40 41 42 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 39 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, error_description: #{@error_description}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 |
# File 'lib/shell_smart_pay_api/exceptions/station_locator_unauthorized_exception.rb', line 32 def unbox(hash) @error_code = hash.key?('errorCode') ? hash['errorCode'] : SKIP @error_description = hash.key?('errorDescription') ? hash['errorDescription'] : SKIP end |