Class: ShellSmartPayApi::AccessTokenResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellSmartPayApi::AccessTokenResponse
- Defined in:
- lib/shell_smart_pay_api/models/access_token_response.rb
Overview
AccessTokenResponse Model.
Instance Attribute Summary collapse
-
#access_token ⇒ String
It is the token used for the requests that required an authenticated user.
-
#expires_in ⇒ String
validity of the access token in seconds.
-
#token_type ⇒ String
Type of token provided.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token = SKIP, expires_in = SKIP, token_type = 'Bearer') ⇒ AccessTokenResponse
constructor
A new instance of AccessTokenResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token = SKIP, expires_in = SKIP, token_type = 'Bearer') ⇒ AccessTokenResponse
Returns a new instance of AccessTokenResponse.
48 49 50 51 52 53 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 48 def initialize(access_token = SKIP, expires_in = SKIP, token_type = 'Bearer') @access_token = access_token unless access_token == SKIP @expires_in = expires_in unless expires_in == SKIP @token_type = token_type unless token_type == SKIP end |
Instance Attribute Details
#access_token ⇒ String
It is the token used for the requests that required an authenticated user. This will be used for all the callback URLs.
15 16 17 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 15 def access_token @access_token end |
#expires_in ⇒ String
validity of the access token in seconds
19 20 21 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 19 def expires_in @expires_in end |
#token_type ⇒ String
Type of token provided
23 24 25 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 23 def token_type @token_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : SKIP expires_in = hash.key?('expires_in') ? hash['expires_in'] : SKIP token_type = hash['token_type'] ||= 'Bearer' # Create object from extracted values. AccessTokenResponse.new(access_token, expires_in, token_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['access_token'] = 'access_token' @_hash['expires_in'] = 'expires_in' @_hash['token_type'] = 'token_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 35 def self.optionals %w[ access_token expires_in token_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_token: #{@access_token.inspect}, expires_in: #{@expires_in.inspect},"\ " token_type: #{@token_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/shell_smart_pay_api/models/access_token_response.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_token: #{@access_token}, expires_in: #{@expires_in}, token_type:"\ " #{@token_type}>" end |